@@ -87,8 +87,8 @@ impl<V> XmlMap<V> {
 	#[inline(always)]
 	pub fn get<'a, NS: Ord + Hash + Eq + ?Sized, N: Ord + Hash + Eq + ?Sized>(
 		&'a self,
-		namespace: &'a NS,
-		name: &'a N,
+		namespace: &NS,
+		name: &N,
 	) -> Option<&'a V>
 	where
 		Namespace: Borrow<NS>,
@@ -140,8 +140,8 @@ impl<V> XmlMap<V> {
 	/// ```
 	pub fn get_mut<'a, NS: Ord + Hash + Eq + ?Sized, N: Ord + Hash + Eq + ?Sized>(
 		&'a mut self,
-		namespace: &'a NS,
-		name: &'a N,
+		namespace: &NS,
+		name: &N,
 	) -> Option<&'a mut V>
 	where
 		Namespace: Borrow<NS>,
@@ -923,3 +923,28 @@ impl<V> Extend<((Namespace, NcName), V)> for XmlMap<V> {
 		}
 	}
 }
+
+#[cfg(test)]
+mod tests {
+	use super::*;
+
+	#[test]
+	fn xml_map_get_does_not_borrow_namespace_or_name() {
+		fn foo<'a>(map: &'a AttrMap, ns: Namespace, name: NcName) -> Option<&'a String> {
+			map.get(&ns, &name)
+		}
+
+		let map = AttrMap::new();
+		foo(&map, Namespace::NONE, NcName::try_from("foo").unwrap());
+	}
+
+	#[test]
+	fn xml_map_get_mut_does_not_borrow_namespace_or_name() {
+		fn foo<'a>(map: &'a mut AttrMap, ns: Namespace, name: NcName) -> Option<&'a mut String> {
+			map.get_mut(&ns, &name)
+		}
+
+		let mut map = AttrMap::new();
+		foo(&mut map, Namespace::NONE, NcName::try_from("foo").unwrap());
+	}
+}
